move_fixture

Function move_fixture 

pub fn move_fixture(
    name: String,
    new_channel: ChannelIndex,
    new_universe: usize,
) -> Result<(), FixtureError>
Relocates an existing fixture to a new channel and/or universe.

Arguments

  • name - Name of the fixture to move
  • new_channel - New starting DMX channel index
  • new_universe - New target DMX universe index (0-based)

Errors

  • [InvalidFixture] – if the fixture name is not found
  • [ChannelAlreadyInUse] – if the new target channels are blocked
  • ChannelOutOfRange - if the new channel range is out of bounds
  • [UniverseOutOfRange] - if the fixture is in a non-existent universe
  • [DmxStateDesync] - if the DMX-State and the fixture registry are out of sync