pub fn remove_fixture(name: String) -> Result<(), FixtureError>Expand description
Removes a fixture instance and frees its associated DMX channel reservations.
Arguments
name- Name of the fixture to remove
Errors
- [
InvalidFixture] – if the fixture does not exist - [
UniverseOutOfRange] - if the fixture is in a non-existent universe - [
DmxStateDesync] - if the DMX-State and the fixture registry are out of sync